# crfsuite-rs

[![Build Status](https://travis-ci.org/bosondata/crfsuite-rs.svg?branch=master)](https://travis-ci.org/bosondata/crfsuite-rs)
[![codecov](https://codecov.io/gh/bosondata/crfsuite-rs/branch/master/graph/badge.svg)](https://codecov.io/gh/bosondata/crfsuite-rs)
[![Crates.io](https://img.shields.io/crates/v/crfsuite.svg)](https://crates.io/crates/crfsuite)
[![docs.rs](https://docs.rs/crfsuite/badge.svg)](https://docs.rs/crfsuite/)

Rust binding to [crfsuite](https://github.com/chokkan/crfsuite)

## Installation

Add it to your ``Cargo.toml``:

```toml
[dependencies]
crfsuite = "0.1"
```

Add ``extern crate crfsuite`` to your crate root and your're good to go!

## License

This work is released under the MIT license. A copy of the license is provided in the [LICENSE](./LICENSE) file.

